# Fill-In-the-Blanks { points=6 }

Complete the missing words in the Ezekiel 25:17 passage below:

"The [path] of the righteous man is beset on all sides by the inequities of the selfish and the [tyranny] of evil men. Blessed is he who, in the name of charity and good will, shepherds the weak through the [valley] of the darkness. For he is truly his brother's keeper and the finder of lost children. And I will strike down upon thee with great vengeance and furious anger those who attempt to [poison] and destroy my [brothers]. And you will know I am the Lord when I lay my [vengeance] upon you."
